==> ejc-proequipmentcorp-impl-3.0.0-20221020.151200-42-sources.jar: com/ejianc/business/proequipmentcorprent/ac/vo/ContractDetailVO.java <==
package com.ejianc.business.proequipmentcorprent.ac.vo;

import java.math.*;
import java.util.ArrayList;
import java.util.List;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.business.proequipmentcorprent.ac.utils.ITreeNodeB;


/**
 * 安拆合同明细
 * 
 * @author generator
 * 
 */
public class ContractDetailVO extends BaseVO implements ITreeNodeB  {
    private static final long serialVersionUID = 1L;
    
    private String detailCode; // 清单编号
    private String detailName; // 
    private String treeIndex; // 序号
    private String detailWorkContent; // 工作内容
    private String detailMeasurementRules; // 计量规则
    private String detailUnit; // 单位
    private BigDecimal detailNum; // 工程量
    private BigDecimal detailPrice; // 单价（无税）
    private BigDecimal detailTaxRate; // 税率
    private BigDecimal detailMny; // 金额（无税）
    private BigDecimal detailTaxPrice; // 单价(含税）
    private BigDecimal detailTaxMny; // 金额（含税）
    private BigDecimal detailTax; // 税额
    private String detailMemo; // 备注
    private Long sourceId; // 来源数据Id
    private String sourceType; // 来源类型：1-定标结果带入
    private Long contractId; // 所属合同Id(合同表主键相当于pid)
    private Long changeId; // 变更表主键
    private Long changeBid; // 变更子表主键
    private Long parentId; // 父ID
    private String changeType; // 变更类型
    private Long docCategoryId; // 档案分类id
    private Long docId; // 档案Id
    private Long planId; // 总计划id（总计划来源的数据的总计划id）
    private String acMemo; // 安拆内容
    private Long categoryId; // 设备分类id
    private String categoryName; // 设备分类
    private String equipmentCode; // 设备编号
    private Long equipmentId; // 设备id
    private String spec; // 规格型号
    private String name; // 机械设备名称

    private String tid;
    private String tpid;
    private List<ITreeNodeB> children;
    

    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }
    public String getDetailWorkContent() {
        return detailWorkContent;
    }

    public void setDetailWorkContent(String detailWorkContent) {
        this.detailWorkContent = detailWorkContent;
    }
    public String getDetailMeasurementRules() {
        return detailMeasurementRules;
    }

    public void setDetailMeasurementRules(String detailMeasurementRules) {
        this.detailMeasurementRules = detailMeasurementRules;
    }
    public String getDetailUnit() {
        return detailUnit;
    }

    public void setDetailUnit(String detailUnit) {
        this.detailUnit = detailUnit;
    }
    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }
    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }
    public BigDecimal getDetailTaxRate() {
        return detailTaxRate;
    }

    public void setDetailTaxRate(BigDecimal detailTaxRate) {
        this.detailTaxRate = detailTaxRate;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }
    public BigDecimal getDetailTaxMny() {
        return detailTaxMny;
    }

    public void setDetailTaxMny(BigDecimal detailTaxMny) {
        this.detailTaxMny = detailTaxMny;
    }
    public BigDecimal getDetailTax() {
        return detailTax;
    }

    public void setDetailTax(BigDecimal detailTax) {
        this.detailTax = detailTax;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    @Override
    public Long getNodeID() {
        return null;
    }

    @Override
    public Long getParentID() {
        return null;
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }

    public void setChildren(List<ITreeNodeB> children) {
        this.children = children;
    }

    public String getAcMemo() {
        return acMemo;
    }

    public void setAcMemo(String acMemo) {
        this.acMemo = acMemo;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
}

==> ejc-proequipmentcorp-impl-3.0.0-20230215.092206-323-sources.jar: com/ejianc/business/proequipmentcorprent/ac/vo/ContractDetailVO.java <==
package com.ejianc.business.proequipmentcorprent.ac.vo;

import java.math.*;
import java.util.ArrayList;
import java.util.List;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.ejianc.business.proequipmentcorprent.ac.utils.ITreeNodeB;


/**
 * 安拆合同明细
 * 
 * @author generator
 * 
 */
public class ContractDetailVO extends BaseVO implements ITreeNodeB  {
    private static final long serialVersionUID = 1L;
    
    private String detailCode; // 清单编号
    private String detailName; // 
    private String treeIndex; // 序号
    private String detailWorkContent; // 工作内容
    private String detailMeasurementRules; // 计量规则
    private String detailUnit; // 单位
    private BigDecimal detailNum; // 工程量
    private BigDecimal detailPrice; // 单价（无税）
    private BigDecimal detailTaxRate; // 税率
    private BigDecimal detailMny; // 金额（无税）
    private BigDecimal detailTaxPrice; // 单价(含税）
    private BigDecimal detailTaxMny; // 金额（含税）
    private BigDecimal detailTax; // 税额
    private String detailMemo; // 备注
    private Long sourceId; // 来源数据Id
    private String sourceType; // 来源类型：1-定标结果带入
    private Long contractId; // 所属合同Id(合同表主键相当于pid)
    private Long changeId; // 变更表主键
    private Long changeBid; // 变更子表主键
    private Long parentId; // 父ID
    private String changeType; // 变更类型
    private Long docCategoryId; // 档案分类id
    private Long docId; // 档案Id
    private Long planId; // 总计划id（总计划来源的数据的总计划id）
    private String acMemo; // 安拆内容
    private Long categoryId; // 设备分类id
    private String categoryName; // 设备分类
    private String equipmentCode; // 设备编号
    private Long equipmentId; // 设备id
    private String spec; // 规格型号
    private String name; // 机械设备名称

    private String tid;
    private String tpid;
    private List<ITreeNodeB> children;
    private String detailTaxPriceStr;
    private String detailTaxMnyStr;
    private String detailTaxRateStr;
    private String detailPriceStr;
    private String detailMnyStr;
    private String detailTaxStr;

    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    public String getDetailName() {
        return detailName;
    }

    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    public String getTreeIndex() {
        return treeIndex;
    }

    public void setTreeIndex(String treeIndex) {
        this.treeIndex = treeIndex;
    }
    public String getDetailWorkContent() {
        return detailWorkContent;
    }

    public void setDetailWorkContent(String detailWorkContent) {
        this.detailWorkContent = detailWorkContent;
    }
    public String getDetailMeasurementRules() {
        return detailMeasurementRules;
    }

    public void setDetailMeasurementRules(String detailMeasurementRules) {
        this.detailMeasurementRules = detailMeasurementRules;
    }
    public String getDetailUnit() {
        return detailUnit;
    }

    public void setDetailUnit(String detailUnit) {
        this.detailUnit = detailUnit;
    }
    public BigDecimal getDetailNum() {
        return detailNum;
    }

    public void setDetailNum(BigDecimal detailNum) {
        this.detailNum = detailNum;
    }
    public BigDecimal getDetailPrice() {
        return detailPrice;
    }

    public void setDetailPrice(BigDecimal detailPrice) {
        this.detailPrice = detailPrice;
    }
    public BigDecimal getDetailTaxRate() {
        return detailTaxRate;
    }

    public void setDetailTaxRate(BigDecimal detailTaxRate) {
        this.detailTaxRate = detailTaxRate;
    }
    public BigDecimal getDetailMny() {
        return detailMny;
    }

    public void setDetailMny(BigDecimal detailMny) {
        this.detailMny = detailMny;
    }
    public BigDecimal getDetailTaxPrice() {
        return detailTaxPrice;
    }

    public void setDetailTaxPrice(BigDecimal detailTaxPrice) {
        this.detailTaxPrice = detailTaxPrice;
    }
    public BigDecimal getDetailTaxMny() {
        return detailTaxMny;
    }

    public void setDetailTaxMny(BigDecimal detailTaxMny) {
        this.detailTaxMny = detailTaxMny;
    }
    public BigDecimal getDetailTax() {
        return detailTax;
    }

    public void setDetailTax(BigDecimal detailTax) {
        this.detailTax = detailTax;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    public String getChangeType() {
        return changeType;
    }

    public void setChangeType(String changeType) {
        this.changeType = changeType;
    }
    public Long getDocCategoryId() {
        return docCategoryId;
    }

    public void setDocCategoryId(Long docCategoryId) {
        this.docCategoryId = docCategoryId;
    }
    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    @Override
    public Long getNodeID() {
        return null;
    }

    @Override
    public Long getParentID() {
        return null;
    }

    @Override
    public List<ITreeNodeB> getChildren() {
        if (children == null) {
            children = new ArrayList<>();
        }
        return children;
    }

    public void setChildren(List<ITreeNodeB> children) {
        this.children = children;
    }

    public String getAcMemo() {
        return acMemo;
    }

    public void setAcMemo(String acMemo) {
        this.acMemo = acMemo;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }

    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDetailTaxPriceStr() {
        return detailTaxPriceStr;
    }

    public void setDetailTaxPriceStr(String detailTaxPriceStr) {
        this.detailTaxPriceStr = detailTaxPriceStr;
    }

    public String getDetailTaxMnyStr() {
        return detailTaxMnyStr;
    }

    public void setDetailTaxMnyStr(String detailTaxMnyStr) {
        this.detailTaxMnyStr = detailTaxMnyStr;
    }

    public String getDetailTaxRateStr() {
        return detailTaxRateStr;
    }

    public void setDetailTaxRateStr(String detailTaxRateStr) {
        this.detailTaxRateStr = detailTaxRateStr;
    }

    public String getDetailPriceStr() {
        return detailPriceStr;
    }

    public void setDetailPriceStr(String detailPriceStr) {
        this.detailPriceStr = detailPriceStr;
    }

    public String getDetailMnyStr() {
        return detailMnyStr;
    }

    public void setDetailMnyStr(String detailMnyStr) {
        this.detailMnyStr = detailMnyStr;
    }

    public String getDetailTaxStr() {
        return detailTaxStr;
    }

    public void setDetailTaxStr(String detailTaxStr) {
        this.detailTaxStr = detailTaxStr;
    }
}
